svn commit: r298027 - head/sys/cam/ata

Warner Losh imp at FreeBSD.org
Fri Apr 15 03:10:06 UTC 2016


Author: imp
Date: Fri Apr 15 03:10:04 2016
New Revision: 298027
URL: https://svnweb.freebsd.org/changeset/base/298027

Log:
  Add FCCT M500 to the NCQ black list. Linux added it in 4.2 (August
  2015). Correct the M500 firmware versions. EU07 was the engineering
  test version, not the release version with the fix. MU07 is the
  release version. It's the only Micron firmware version to actually
  work. Remove support for EU07.
  
  This brings the blacklist into parity with the Linux blacklist as of
  4.5, except for the Micron M500 MU07 entry. I personally tested the
  MU07 firmware on 12 machines running 6 drives each with no corruption
  in the past 6 months with Netflix production loads. Prior versions of
  the M500 firmware wouldn't last more than a few days.
  
  Sponsored by: Netflix, Inc.

Modified:
  head/sys/cam/ata/ata_da.c

Modified: head/sys/cam/ata/ata_da.c
==============================================================================
--- head/sys/cam/ata/ata_da.c	Fri Apr 15 03:09:58 2016	(r298026)
+++ head/sys/cam/ata/ata_da.c	Fri Apr 15 03:10:04 2016	(r298027)
@@ -361,10 +361,10 @@ static struct ada_quirk_entry ada_quirk_
 	},
 	{
 		/*
 		 * Crucial M500 SSDs EU07 firmware
 		 * NCQ Trim works ? 
 		 */
-		{ T_DIRECT, SIP_MEDIA_FIXED, "*", "Crucial CT*M500*", "EU07" },
+		{ T_DIRECT, SIP_MEDIA_FIXED, "*", "Crucial CT*M500*", "MU07" },
 		/*quirks*/0
 	},
 	{
@@ -401,6 +401,14 @@ static struct ada_quirk_entry ada_quirk_
 	},
 	{
 		/*
+		 * FCCT M500 SSDs
+		 * NCQ Trim doesn't work
+		 */
+		{ T_DIRECT, SIP_MEDIA_FIXED, "*", "FCCT*M500*", "*" },
+		/*quirks*/ADA_Q_NCQ_TRIM_BROKEN
+	},
+	{
+		/*
 		 * Intel 320 Series SSDs
 		 * 4k optimised & trim only works in 4k requests + 4k aligned
 		 */
@@ -465,10 +473,10 @@ static struct ada_quirk_entry ada_quirk_
 	},
 	{
 		/*
 		 * Micron M500 SSDs firmware EU07
 		 * NCQ Trim works?
 		 */
-		{ T_DIRECT, SIP_MEDIA_FIXED, "*", "Micron M500*", "EU07" },
+		{ T_DIRECT, SIP_MEDIA_FIXED, "*", "Micron M500*", "MU07" },
 		/*quirks*/0
 	},
 	{
@@ -361,10 +361,10 @@ static struct ada_quirk_entry ada_quirk_
 	{
 		/*
-		 * Crucial M500 SSDs EU07 firmware
-		 * NCQ Trim works ? 
+		 * Crucial M500 SSDs MU07 firmware
+		 * NCQ Trim works
 		 */
@@ -465,10 +473,10 @@ static struct ada_quirk_entry ada_quirk_
 	{
 		/*
-		 * Micron M500 SSDs firmware EU07
+		 * Micron M500 SSDs firmware MU07
 		 * NCQ Trim works?
 		 */


More information about the svn-src-head mailing list